@@ -43,14 +43,16 @@ class Params:
         """
         self.q = {}
 
+        if isinstance(environ, (dict,)) and not "REQUEST_METHOD" in environ:
+            self.q = environ
 
-        if environ and "REQUEST_METHOD" in environ and environ["REQUEST_METHOD"]=="GET":
+        elif environ and "REQUEST_METHOD" in environ and environ["REQUEST_METHOD"] == "GET":
             request_body = environ['QUERY_STRING']
             q = parse_qs(request_body)
             for key in q:
                 self.q[key] = [escape(item) for item in q[key]]
 
-        elif environ and "REQUEST_METHOD" in environ and environ["REQUEST_METHOD"]=="POST":
+        elif environ and "REQUEST_METHOD" in environ and environ["REQUEST_METHOD"] == "POST":
 
             env_copy = environ.copy()
             env_copy['QUERY_STRING']=''
@@ -64,18 +66,20 @@ class Params:
             q = parse_qs(request_body)
             for key in q:
                 self.q[key] = [escape(item) for item in q[key]]
-
+                
         elif environ:
             self.q = environ
 
-
         if environ and "DOCUMENT_ROOT" in environ:
             self.q["DOCUMENT_ROOT"] = environ["DOCUMENT_ROOT"]
             environ["DOCUMENT_WWW"] = os.path.abspath(environ["DOCUMENT_ROOT"] + "/var/www")
             self.q["DOCUMENT_WWW"] = environ["DOCUMENT_WWW"]
 
         if environ and "HTTP_COOKIE" in environ:
-            self.q["HTTP_COOKIE"] = mapify(environ["HTTP_COOKIE"], ";")
+            if isinstance(environ["HTTP_COOKIE"], (str,)):
+                self.q["HTTP_COOKIE"] = mapify(environ["HTTP_COOKIE"], ";")
+            else:
+                self.q["HTTP_COOKIE"] = environ["HTTP_COOKIE"]
 
         if "encoded" in self.q and self.q["encoded"] in ("true","1",1):
             for key in q:
